@@ -16,6 +16,7 @@ from urllib.parse import quote
 import aiohttp
 import requests.utils
 import rsa
+import urllib3.exceptions
 from requests.adapters import HTTPAdapter, Retry
 
 from biliup import config
@@ -29,7 +30,7 @@ class BiliWeb(UploadBase):
                  lines='AUTO', threads=3, tid=122, tags=None, cover_path=None, description=''):
         super().__init__(principal, data, persistence_path='bili.cookie', postprocessor=postprocessor)
         if tags is None:
-            tags = ['星际争霸2', '电子竞技']
+            tags = []
         self.user = user
         self.lines = lines
         self.submit_api = submit_api
@@ -52,7 +53,7 @@ class BiliWeb(UploadBase):
             video.title = self.data["format_title"]
             video.desc = self.desc + '''
             Powered By biliup
-            Github：https://github.com/ForgQi/biliup (或者在Github搜索ForgQi)交流群：837362626'''
+            Github：https://github.com/ForgQi/biliup'''
             video.copyright = self.copyright
             if self.copyright == 2:
                 video.source = self.data["url"]  # 添加转载地址说明
@@ -338,11 +339,20 @@ class BiliBili:
             'output': 'json',
             'profile': 'ugcupos/bup'
         }
-        r = self.__session.post(url, params=p, json={"parts": parts}, headers=headers, timeout=15).json()
-        logger.info(f'{filename} uploaded >> {total_size / 1000 / 1000 / cost:.2f}MB/s. {r}')
+        ii = 0
+        while ii <= 3:
+            try:
+                r = self.__session.post(url, params=p, json={"parts": parts}, headers=headers, timeout=15).json()
+                if r.get('OK') == 1:
+                    logger.info(f'{filename} uploaded >> {total_size / 1000 / 1000 / cost:.2f}MB/s. {r}')
+                    return {"title": splitext(filename)[0], "filename": splitext(basename(upos_uri))[0], "desc": ""}
+            except(urllib3.exceptions.ReadTimeoutError, urllib3.exceptions.MaxRetryError,
+                   requests.exceptions.ConnectionError):
+                ii += 1
+                logger.info("上传出现问题，尝试重连，次数：" + str(ii))
+                time.sleep(15)
         if r.get('OK') != 1:
             raise Exception(r)
-        return {"title": splitext(filename)[0], "filename": splitext(basename(upos_uri))[0], "desc": ""}
 
     @staticmethod
     async def _upload(params, file, chunk_size, afunc, tasks=3):
@@ -519,6 +529,8 @@ class Data:
 
     def set_tag(self, tag: list):
         """设置标签，tag为数组"""
+        if 'biliup' not in tag:
+            tag.append('biliup')
         self.dynamic = f"#{'##'.join(tag)}#"
         self.tag = ','.join(tag)
 
