@@ -16,7 +16,9 @@ def upload(platform, index, data):
     :return:
     """
     try:
-        cls = Plugin.upload_plugins[platform]
+        cls = Plugin.upload_plugins.get(platform)
+        if cls is None:
+            return logger.error(f"No such uploader: {platform}")
         sig = inspect.signature(cls)
         context = {**engine.config, **engine.config['streamers'][index]}
         kwargs = {}
@@ -25,6 +27,9 @@ def upload(platform, index, data):
             if v:
                 kwargs[k] = v
         date = data.get("date") if data.get("date") else ""
+        threshold = engine.config.get('filtering_threshold')
+        if threshold:
+            data['threshold'] = threshold
         if data.get("format_title") is None:
             data["format_title"] = f"{date}{index}"
         return cls(index, data, **kwargs).start()
